@@ -1592,6 +1592,29 @@ pdf_document_file_exporter_begin (EvFileExporter        *exporter,
 #endif
 }
 
+static void
+pdf_document_file_exporter_begin_page (EvFileExporter *exporter)
+{
+	PdfDocument *pdf_document = PDF_DOCUMENT (exporter);
+	PdfPrintContext *ctx = pdf_document->print_ctx;
+	
+	g_return_if_fail (pdf_document->print_ctx != NULL);
+
+	ctx->pages_printed = 0;
+
+	if (ctx->paper_width > ctx->paper_height) {
+		if (ctx->format == EV_FILE_FORMAT_PS) {
+			cairo_ps_surface_set_size (cairo_get_target (ctx->cr),
+						   ctx->paper_height,
+						   ctx->paper_width);
+		} else if (ctx->format == EV_FILE_FORMAT_PDF) {
+			cairo_pdf_surface_set_size (cairo_get_target (ctx->cr),
+						    ctx->paper_height,
+						    ctx->paper_width);
+		}
+	}
+}
+
 static void
 pdf_document_file_exporter_do_page (EvFileExporter  *exporter,
 				    EvRenderContext *rc)
@@ -1630,9 +1653,6 @@ pdf_document_file_exporter_do_page (EvFileExporter  *exporter,
 		width = ctx->paper_height;
 		height = ctx->paper_width;
 		rotate = !rotate;
-
-		cairo_ps_surface_set_size (cairo_get_target (ctx->cr),
-					   width, height);
 	} else {
 		width = ctx->paper_width;
 		height = ctx->paper_height;
@@ -1653,7 +1673,6 @@ pdf_document_file_exporter_do_page (EvFileExporter  *exporter,
 		tmp2 = page_width;
 		page_width = page_height;
 		page_height = tmp2;
-
 	}
 
 	pwidth = width / ctx->pages_x;
@@ -1692,15 +1711,17 @@ pdf_document_file_exporter_do_page (EvFileExporter  *exporter,
 			 x * (rotate ? pheight : pwidth),
 			 y * (rotate ? pwidth : pheight));
 	cairo_scale (ctx->cr, xscale, yscale);
-	
+
+#ifdef HAVE_POPPLER_PAGE_RENDER_FOR_PRINTING
+	poppler_page_render_for_printing (poppler_page, ctx->cr);
+#else
 #ifdef HAVE_POPPLER_PAGE_RENDER
 	poppler_page_render (poppler_page, ctx->cr);
 #endif
+#endif
+
 	ctx->pages_printed++;
 			
-	if (ctx->pages_printed % ctx->pages_per_sheet == 0) {
-		cairo_show_page (ctx->cr);
-	}
 	cairo_restore (ctx->cr);
 #else /* HAVE_CAIRO_PRINT */
 	if (ctx->format == EV_FILE_FORMAT_PS)
@@ -1710,6 +1731,17 @@ pdf_document_file_exporter_do_page (EvFileExporter  *exporter,
 	g_object_unref (poppler_page);
 }
 
+static void
+pdf_document_file_exporter_end_page (EvFileExporter *exporter)
+{
+	PdfDocument *pdf_document = PDF_DOCUMENT (exporter);
+	PdfPrintContext *ctx = pdf_document->print_ctx;
+	
+	g_return_if_fail (pdf_document->print_ctx != NULL);
+
+	cairo_show_page (ctx->cr);
+}
+
 static void
 pdf_document_file_exporter_end (EvFileExporter *exporter)
 {
@@ -1748,7 +1780,9 @@ static void
 pdf_document_file_exporter_iface_init (EvFileExporterIface *iface)
 {
         iface->begin = pdf_document_file_exporter_begin;
+	iface->begin_page = pdf_document_file_exporter_begin_page;
         iface->do_page = pdf_document_file_exporter_do_page;
+	iface->end_page = pdf_document_file_exporter_end_page;
         iface->end = pdf_document_file_exporter_end;
 	iface->get_capabilities = pdf_document_file_exporter_get_capabilities;
 }
@@ -2048,7 +2082,7 @@ ev_form_field_from_poppler_field (PopplerFormField *poppler_field)
 			ev_field = ev_form_field_signature_new (id);
 			break;
 	        case POPPLER_FORM_FIELD_UNKNOWN:
-			break;
+			return NULL;
 	}
 
 	ev_field->font_size = font_size;
@@ -2067,7 +2101,6 @@ pdf_document_forms_get_form_fields (EvDocumentForms *document,
  	GList *fields;
  	GList *list;
  	double height;
-	
 
  	pdf_document = PDF_DOCUMENT (document);
  	poppler_page = poppler_document_get_page (pdf_document->document, page);
@@ -2077,19 +2110,25 @@ pdf_document_forms_get_form_fields (EvDocumentForms *document,
  	for (list = fields; list; list = list->next) {
  		PopplerFormFieldMapping *mapping;
  		EvFormFieldMapping *field_mapping;
-		
+		EvFormField *ev_field;
+
  		mapping = (PopplerFormFieldMapping *)list->data;
 
+		ev_field = ev_form_field_from_poppler_field (mapping->field);
+		if (!ev_field)
+			continue;
+
  		field_mapping = g_new0 (EvFormFieldMapping, 1);
 		field_mapping->x1 = mapping->area.x1;
 		field_mapping->x2 = mapping->area.x2;
 		field_mapping->y1 = height - mapping->area.y2;
 		field_mapping->y2 = height - mapping->area.y1;
-		field_mapping->field = ev_form_field_from_poppler_field (mapping->field);
+		field_mapping->field = ev_field;
 		field_mapping->field->page = page;
 		
 		retval = g_list_prepend (retval, field_mapping);
 	}
+	
 	poppler_page_free_form_field_mapping (fields);
 	g_object_unref (poppler_page);
 
