@@ -152,7 +152,7 @@ ev_document_misc_surface_from_pixbuf (GdkPixbuf *pixbuf)
 	cairo_surface_t *surface;
 	cairo_t         *cr;
 	
-	surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+	surface = cairo_image_surface_create (CAIRO_FORMAT_RGB24,
 					      gdk_pixbuf_get_width (pixbuf),
 					      gdk_pixbuf_get_height (pixbuf));
 	cr = cairo_create (surface);
@@ -257,7 +257,7 @@ ev_document_misc_surface_rotate_and_scale (cairo_surface_t *surface,
 	}
 
 	new_surface = cairo_surface_create_similar (surface,
-						    CAIRO_CONTENT_COLOR_ALPHA,
+						    cairo_surface_get_content (surface),
 						    new_width, new_height);
 
 	cr = cairo_create (new_surface);
