@@ -118,12 +118,13 @@ void            ev_view_set_rotation      (EvView         *view,
 int             ev_view_get_rotation      (EvView         *view);
 
 /* Find */
-gboolean        ev_view_can_find_next     (EvView         *view);
-void            ev_view_find_next         (EvView         *view);
-gboolean        ev_view_can_find_previous (EvView         *view);
-void            ev_view_find_previous     (EvView         *view);
-void            ev_view_search_changed    (EvView         *view);
-
+gboolean        ev_view_can_find_next        (EvView         *view);
+void            ev_view_find_next            (EvView         *view);
+gboolean        ev_view_can_find_previous    (EvView         *view);
+void            ev_view_find_previous        (EvView         *view);
+void            ev_view_search_changed       (EvView         *view);
+void     	ev_view_set_highlight_search (EvView         *view,
+					      gboolean        value);
 /* Status */
 const char     *ev_view_get_status        (EvView         *view);
 const char     *ev_view_get_find_status   (EvView         *view);
